==> jc-1.4.0.tar.gz: java/text/DateFormat__24Field.h <==
// public class java.text.DateFormat$Field

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute
// @dep_class da22ab3b871e651e java_text_DateFormat__24Field
// @dep_class 732f8dfeca4d477 java_text_Format__24Field

// header file dependencies
// @dep_header java_text_Format__24Field

#include "java/text/Format__24Field.h"

#ifndef _JC_java_text_DateFormat__24Field_H_
#define _JC_java_text_DateFormat__24Field_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_DateFormat__24Field$object;

// Typedefs
typedef struct _jc_java_text_DateFormat__24Field$sub_refs	_jc_java_text_DateFormat__24Field$sub_refs;
typedef struct _jc_java_text_DateFormat__24Field$sub_nonrefs	_jc_java_text_DateFormat__24Field$sub_nonrefs;
typedef struct _jc_java_text_DateFormat__24Field$refs	_jc_java_text_DateFormat__24Field$refs;
typedef struct _jc_java_text_DateFormat__24Field$nonrefs	_jc_java_text_DateFormat__24Field$nonrefs;
typedef struct _jc_java_text_DateFormat__24Field$object	_jc_java_text_DateFormat__24Field$object;

typedef struct _jc_java_text_DateFormat__24Field$fields_struct	_jc_java_text_DateFormat__24Field$fields_struct;
typedef const struct _jc_java_text_DateFormat__24Field$vmethods	_jc_java_text_DateFormat__24Field$vmethods;
typedef const struct _jc_java_text_DateFormat__24Field$vtable	_jc_java_text_DateFormat__24Field$vtable;
typedef const struct _jc_java_text_DateFormat__24Field$vtype	_jc_java_text_DateFormat__24Field$vtype;

// Class fields structure
struct _jc_java_text_DateFormat__24Field$fields_struct {
	struct _jc_java_text_DateFormat__24Field$object	*AM__5fPM;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fMONTH;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fWEEK;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fWEEK__5fIN__5fMONTH;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*ERA;
	struct _jc_java_text_DateFormat__24Field$object	*EXTENDED__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR0;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR1;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR__5fOF__5fDAY0;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR__5fOF__5fDAY1;
	struct _jc_java_text_DateFormat__24Field$object	*ISO__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*LOCALIZED__5fDAY__5fOF__5fWEEK;
	struct _jc_java_text_DateFormat__24Field$object	*MILLISECOND;
	struct _jc_java_text_DateFormat__24Field$object	*MILLISECOND__5fIN__5fDAY;
	struct _jc_java_text_DateFormat__24Field$object	*MINUTE;
	struct _jc_java_text_DateFormat__24Field$object	*MODIFIED__5fJULIAN__5fDAY;
	struct _jc_java_text_DateFormat__24Field$object	*MONTH;
	struct _jc_java_text_DateFormat__24Field$object	*RFC822__5fTIME__5fZONE;
	struct _jc_java_text_DateFormat__24Field$object	*SECOND;
	struct _jc_java_text_DateFormat__24Field$object	*TIME__5fZONE;
	struct _jc_java_text_DateFormat__24Field$object	*WEEK__5fOF__5fMONTH;
	struct _jc_java_text_DateFormat__24Field$object	*WEEK__5fOF__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*YEAR;
	_jc_object_array	*allFields;
	jlong	serialVersionUID;
};
extern _jc_java_text_DateFormat__24Field$fields_struct _jc_java_text_DateFormat__24Field$class_fields;

// Constructors
extern void _jc_java_text_DateFormat__24Field$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *);
extern void _jc_java_text_DateFormat__24Field$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern jint _jc_java_text_DateFormat__24Field$method$getCalendarField$730d7fd8db137f7c(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *);
extern struct _jc_java_lang_Object$object *_jc_java_text_DateFormat__24Field$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_DateFormat__24Field$method_info$getCalendarField$730d7fd8db137f7c;
extern _jc_method _jc_java_text_DateFormat__24Field$method_info$readResolve$3c2bccd3a831d3ae;

// Static methods
extern void _jc_java_text_DateFormat__24Field$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_text_DateFormat__24Field$object *_jc_java_text_DateFormat__24Field$method$ofCalendarField$3b5c64968accfe7b(_jc_env *, jint);

// Virtual methods structure
struct _jc_java_text_DateFormat__24Field$vmethods {
	jint	(*getCalendarField$730d7fd8db137f7c)(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *);
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *);
};

// Vtable
struct _jc_java_text_DateFormat__24Field$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
	_jc_java_text_Format__24Field$vmethods	java_text_Format__24Field;
	_jc_java_text_DateFormat__24Field$vmethods	java_text_DateFormat__24Field;
};

// Vtype
struct _jc_java_text_DateFormat__24Field$vtype {
	_jc_type			type;
	_jc_java_text_DateFormat__24Field$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_DateFormat__24Field$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_DateFormat__24Field$refs {
    _jc_java_text_DateFormat__24Field$sub_refs	java_text_DateFormat__24Field;
    _jc_java_text_Format__24Field$sub_refs	java_text_Format__24Field;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_DateFormat__24Field$sub_nonrefs {
	jint	calendarField;
};

// Non-reference instance fields (object)
struct _jc_java_text_DateFormat__24Field$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_text_Format__24Field$sub_nonrefs	java_text_Format__24Field;
    _jc_java_text_DateFormat__24Field$sub_nonrefs	java_text_DateFormat__24Field;
};

// Object instance structure
struct _jc_java_text_DateFormat__24Field$object {
	_jc_java_text_DateFormat__24Field$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_DateFormat__24Field$vtype	*vtype;
	_jc_java_text_DateFormat__24Field$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_DateFormat__24Field$vtype _jc_java_text_DateFormat__24Field$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_DateFormat__24Field, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_DateFormat__24Field$class_object;

#endif	/* _JC_java_text_DateFormat__24Field_H_ */

==> jc-1.4.6.tar.gz: java/text/DateFormat__24Field.h <==
// public class java.text.DateFormat$Field

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute
// @dep_class da22ab3b871e651e java_text_DateFormat__24Field
// @dep_class 732f8dfeca4d477 java_text_Format__24Field

// header file dependencies
// @dep_header java_text_Format__24Field

#include "java/text/Format__24Field.h"

#ifndef _JC_java_text_DateFormat__24Field_H_
#define _JC_java_text_DateFormat__24Field_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_DateFormat__24Field$object;

// Typedefs
typedef struct _jc_java_text_DateFormat__24Field$sub_refs	_jc_java_text_DateFormat__24Field$sub_refs;
typedef struct _jc_java_text_DateFormat__24Field$sub_nonrefs	_jc_java_text_DateFormat__24Field$sub_nonrefs;
typedef struct _jc_java_text_DateFormat__24Field$refs	_jc_java_text_DateFormat__24Field$refs;
typedef struct _jc_java_text_DateFormat__24Field$nonrefs	_jc_java_text_DateFormat__24Field$nonrefs;
typedef struct _jc_java_text_DateFormat__24Field$object	_jc_java_text_DateFormat__24Field$object;

typedef struct _jc_java_text_DateFormat__24Field$fields_struct	_jc_java_text_DateFormat__24Field$fields_struct;
typedef const struct _jc_java_text_DateFormat__24Field$vmethods	_jc_java_text_DateFormat__24Field$vmethods;
typedef const struct _jc_java_text_DateFormat__24Field$vtable	_jc_java_text_DateFormat__24Field$vtable;
typedef const struct _jc_java_text_DateFormat__24Field$vtype	_jc_java_text_DateFormat__24Field$vtype;

// Class fields structure
struct _jc_java_text_DateFormat__24Field$fields_struct {
	struct _jc_java_text_DateFormat__24Field$object	*AM__5fPM;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fMONTH;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fWEEK;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fWEEK__5fIN__5fMONTH;
	struct _jc_java_text_DateFormat__24Field$object	*DAY__5fOF__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*ERA;
	struct _jc_java_text_DateFormat__24Field$object	*EXTENDED__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR0;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR1;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR__5fOF__5fDAY0;
	struct _jc_java_text_DateFormat__24Field$object	*HOUR__5fOF__5fDAY1;
	struct _jc_java_text_DateFormat__24Field$object	*ISO__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*LOCALIZED__5fDAY__5fOF__5fWEEK;
	struct _jc_java_text_DateFormat__24Field$object	*MILLISECOND;
	struct _jc_java_text_DateFormat__24Field$object	*MILLISECOND__5fIN__5fDAY;
	struct _jc_java_text_DateFormat__24Field$object	*MINUTE;
	struct _jc_java_text_DateFormat__24Field$object	*MODIFIED__5fJULIAN__5fDAY;
	struct _jc_java_text_DateFormat__24Field$object	*MONTH;
	struct _jc_java_text_DateFormat__24Field$object	*RFC822__5fTIME__5fZONE;
	struct _jc_java_text_DateFormat__24Field$object	*SECOND;
	struct _jc_java_text_DateFormat__24Field$object	*TIME__5fZONE;
	struct _jc_java_text_DateFormat__24Field$object	*WEEK__5fOF__5fMONTH;
	struct _jc_java_text_DateFormat__24Field$object	*WEEK__5fOF__5fYEAR;
	struct _jc_java_text_DateFormat__24Field$object	*YEAR;
	_jc_object_array	*allFields;
	jlong	serialVersionUID;
};
extern _jc_java_text_DateFormat__24Field$fields_struct _jc_java_text_DateFormat__24Field$class_fields;

// Constructors
extern void _jc_java_text_DateFormat__24Field$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *) _JC_JCNI_ATTR;
extern void _jc_java_text_DateFormat__24Field$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_text_DateFormat__24Field$method$getCalendarField$730d7fd8db137f7c(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_text_DateFormat__24Field$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_DateFormat__24Field$method_info$getCalendarField$730d7fd8db137f7c;
extern _jc_method _jc_java_text_DateFormat__24Field$method_info$readResolve$3c2bccd3a831d3ae;

// Static methods
extern void _jc_java_text_DateFormat__24Field$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_text_DateFormat__24Field$object *_jc_java_text_DateFormat__24Field$method$ofCalendarField$3b5c64968accfe7b(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_text_DateFormat__24Field$vmethods {
	jint	(*getCalendarField$730d7fd8db137f7c)(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_text_DateFormat__24Field$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_DateFormat__24Field$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
	_jc_java_text_Format__24Field$vmethods	java_text_Format__24Field;
	_jc_java_text_DateFormat__24Field$vmethods	java_text_DateFormat__24Field;
};

// Vtype
struct _jc_java_text_DateFormat__24Field$vtype {
	_jc_type			type;
	_jc_java_text_DateFormat__24Field$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_DateFormat__24Field$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_DateFormat__24Field$refs {
    _jc_java_text_DateFormat__24Field$sub_refs	java_text_DateFormat__24Field;
    _jc_java_text_Format__24Field$sub_refs	java_text_Format__24Field;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_DateFormat__24Field$sub_nonrefs {
	jint	calendarField;
};

// Non-reference instance fields (object)
struct _jc_java_text_DateFormat__24Field$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_text_Format__24Field$sub_nonrefs	java_text_Format__24Field;
    _jc_java_text_DateFormat__24Field$sub_nonrefs	java_text_DateFormat__24Field;
};

// Object instance structure
struct _jc_java_text_DateFormat__24Field$object {
	_jc_java_text_DateFormat__24Field$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_DateFormat__24Field$vtype	*vtype;
	_jc_java_text_DateFormat__24Field$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_DateFormat__24Field$vtype _jc_java_text_DateFormat__24Field$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_DateFormat__24Field, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_DateFormat__24Field$class_object;

#endif	/* _JC_java_text_DateFormat__24Field_H_ */
